@@ -42,13 +42,16 @@ use Lintian::Check qw(check_spelling spelling_tag_emitter);
 use Lintian::Data;
 use Lintian::Relation qw(:constants);
 use Lintian::Tags qw(tag);
-use Lintian::Util qw(fail slurp_entire_file strip);
+use Lintian::Util qw(internal_error slurp_entire_file strip);
 
 my $ARCH_REGEX = Lintian::Data->new('binaries/arch-regex', qr/\s*\~\~/o,
     sub { return qr/$_[1]/ });
 my $ARCH_64BIT_EQUIVS
   = Lintian::Data->new('binaries/arch-64bit-equivs', qr/\s*\=\>\s*/);
 
+my %PATH_DIRECTORIES = map { $_ => 1 } qw(
+  bin/ sbin/ usr/bin/ usr/sbin/ usr/games/ );
+
 sub _embedded_libs {
     my ($key, $val, undef) = @_;
     my $result = {'libname' => $key,};
@@ -65,14 +68,14 @@ sub _embedded_libs {
             } elsif ($opt eq 'source-regex') {
                 $result->{$opt} = qr/$val/;
             } else {
-                fail(   "Unknown option $opt used for $key"
+                internal_error("Unknown option $opt used for $key"
                       . ' (in binaries/embedded-libs)');
             }
         }
     }
 
     if (defined $result->{'source'} and $result->{'source-regex'}) {
-        fail(   "Both source and source-regex used for $key"
+        internal_error("Both source and source-regex used for $key"
               . ' (in binaries/embedded-libs)');
     } else {
         $result->{'source'} = $key unless defined $result->{'source'};
@@ -219,7 +222,7 @@ sub run {
     }
 
     # For the package naming check, filter out SONAMEs where all the
-    # files are at paths other than /lib, /usr/lib, or /usr/X11R6/lib.
+    # files are at paths other than /lib, /usr/lib and /usr/lib/<MA-DIR>.
     # This avoids false positives with plugins like Apache modules,
     # which may have their own SONAMEs but which don't matter for the
     # purposes of this check.  Also filter out nsswitch modules
@@ -325,7 +328,8 @@ sub run {
             foreach my $obj (@{ $objdump->{'objects'} }) {
                 my $libobj = $info->objdump_info->{"${file}(${obj})"};
                 # Shouldn't happen, but...
-                fail("object ($file $obj) in static lib is missing!?")
+                internal_error(
+                    "object ($file $obj) in static lib is missing!?")
                   unless defined $libobj;
 
                 if (any { exists($libobj->{'SH'}{$_}) } DEBUG_SECTIONS) {
@@ -341,6 +345,11 @@ sub run {
         # ELF?
         next unless $fileinfo =~ m/^[^,]*\bELF\b/o;
 
+        tag 'development-package-ships-elf-binary-in-path', $file
+          if exists($PATH_DIRECTORIES{$file->dirname})
+          and $info->field('section', 'NONE') =~ m/(?:^|\/)libdevel$/
+          and $info->field('multi-arch', 'NONE') ne 'foreign';
+
         $objdump = $info->objdump_info->{$fname};
 
         if ($arch eq 'all' or not $ARCH_REGEX->known($arch)) {
