@@ -591,6 +591,13 @@ sub run {
 
         tag 'unknown-priority', $priority
           unless $KNOWN_PRIOS->known($priority);
+
+        tag 'excessive-priority-for-library-package', $priority
+          if $pkg =~ m/^lib/o
+          and $pkg !~ m/-bin$/o
+          and $pkg !~ m/^libc[0-9.]+$/o
+          and any { $_ eq $info->field('section', '') } qw(libdevel libs)
+          and any { $_ eq $priority } qw(required important standard);
     }
 
     #---- Standards-Version
@@ -1228,6 +1235,9 @@ sub run {
 
         tag 'redundant-bugs-field'
           if $bugs =~ m,^debbugs://bugs.debian.org/?$,i;
+
+        tag 'bugs-field-does-not-refer-to-debian-infrastructure', "line $."
+          if $bugs !~ m,\.debian\.org,;
     }
 
     #----- Python-Version
@@ -1285,6 +1295,7 @@ sub run {
 
     #----- Vcs-*
 
+    my %seen_vcs;
     while (my ($vcs, $splitter) = each %VCS_EXTRACT) {
         if (defined $info->field("vcs-$vcs")) {
             my $uri = $info->field("vcs-$vcs");
@@ -1324,8 +1335,11 @@ sub run {
             }
             tag 'vcs-browser-links-to-empty-view', $uri
               if $vcs eq 'browser' and $uri =~ m%rev=0&sc=0%;
+            $seen_vcs{$vcs}++ if $vcs ne 'browser';
         }
     }
+    tag 'vcs-fields-use-more-than-one-vcs', sort keys %seen_vcs
+      if keys %seen_vcs > 1;
 
     #---- Checksums
 
