@@ -31,12 +31,14 @@ use Lintian::SlidingWindow;
 
 use constant BLOCKSIZE => 16_384;
 
+my $FNAMES = Lintian::Data->new('files/fnames', qr/\s*\~\~\s*/);
 my $FONT_PACKAGES = Lintian::Data->new('files/fonts', qr/\s++/);
 my $TRIPLETS = Lintian::Data->new('files/triplets', qr/\s++/);
 my $LOCALE_CODES = Lintian::Data->new('files/locale-codes', qr/\s++/);
 my $INCORRECT_LOCALE_CODES
   = Lintian::Data->new('files/incorrect-locale-codes', qr/\s++/);
 my $MULTIARCH_DIRS = Lintian::Data->new('common/multiarch-dirs', qr/\s++/);
+my $GENERIC_PYTHON_MODULES= Lintian::Data->new('files/python-generic-modules');
 
 my $PRIVACY_BREAKER_WEBSITES= Lintian::Data->new(
     'files/privacy-breaker-websites',
@@ -300,6 +302,7 @@ sub run {
     my $pkg_section = $info->field('section', '');
     my $arch = $info->field('architecture', '');
     my $multiarch = $info->field('multi-arch', 'no');
+    my $multiarch_dir = $MULTIARCH_DIRS->value($arch);
     my $ppkg = quotemeta($pkg);
 
     # get the last changelog timestamp
@@ -405,8 +408,10 @@ sub run {
             tag 'file-name-is-not-valid-UTF-8', $file;
         }
 
-        if ($fname =~ m,[*?],) {
-            tag 'file-name-contains-wildcard-character', $file;
+        # check for generic bad filenames
+        foreach my $tag ($FNAMES->all()) {
+            my $regex = $FNAMES->value($tag);
+            tag $tag, $file if $fname =~ m/$regex/;
         }
 
         if ($file->is_hardlink) {
@@ -683,11 +688,12 @@ sub run {
             }
             # ---------------- arch-indep pkgconfig
             elsif ($file->is_regular_file
-                && $fname
-                =~ m,^usr/(?:lib(/[^/]+)?|share)/pkgconfig/[^/]+\.pc$,) {
-                my $pkg_config_arch = $1 // '';
+                && $fname=~ m,^usr/(lib(/[^/]+)?|share)/pkgconfig/[^/]+\.pc$,){
+                my $prefix = $1;
+                my $pkg_config_arch = $2 // '';
                 $pkg_config_arch =~ s,\A/,,ms;
-
+                tag 'pkg-config-unavailable-for-cross-compilation', $file
+                  if $prefix eq 'lib';
                 my $fd = $file->open(':raw');
                 my $sfd = Lintian::SlidingWindow->new($fd);
               BLOCK:
@@ -829,6 +835,9 @@ sub run {
                 } elsif (
                     $dir !~ /^(?:100dpi|75dpi|misc|Type1|encodings|util)$/) {
                     tag 'file-in-unknown-x11-font-directory', $file;
+                } elsif ($file->basename eq 'encodings.dir'
+                    or $file->basename =~ m{fonts\.(dir|scale|alias)}) {
+                    tag 'package-contains-compiled-font-file', $file;
                 }
                 if ($dir =~ /^(?:100dpi|75dpi|misc)$/) {
                     $x11_font_dirs{$dir}++;
@@ -1119,6 +1128,18 @@ sub run {
               ) {
                 tag 'file-in-unusual-dir', $file;
             }
+
+            if (    defined($multiarch_dir)
+                and $multiarch eq 'foreign'
+                and $fname =~ m,^usr/lib/\Q$multiarch_dir\E/(.*)$,) {
+                my $tail = $1;
+                tag 'multiarch-foreign-cmake-file', $file
+                  if ($tail =~ m,^cmake/.+\.cmake$,);
+                tag 'multiarch-foreign-pkgconfig', $file
+                  if ($tail =~ m,^pkgconfig/[^/]+\.pc$,);
+                tag 'multiarch-foreign-static-library', $file
+                  if ($tail =~ m,^lib[^/]+\.a$,);
+            }
         }
 
         if ($fname =~ m,^(?:usr/)?lib/([^/]+)/$,o) {
@@ -1157,11 +1178,6 @@ sub run {
             tag 'package-installs-python-egg', $file;
         }
 
-        # ---------------- .coverage (coverage.py output)
-        if ($file->basename eq '.coverage') {
-            tag 'package-contains-python-coverage-file', $file;
-        }
-
         # ---------------- .class (compiled Java files)
         if (   $fname =~ m,\.class$,o
             && $fname !~ m,(?:WEB-INF|demo|doc|example|sample|test),o) {
@@ -1289,6 +1305,8 @@ sub run {
             # base-files (which is required to ship them)
             and not $fname =~ m,^usr/share/common-licenses/[^/]+$,o
             and not defined $link
+            # Sphinx includes various license files
+            and not $fname =~ m,/_sources/license(\.rst)?\.txt$,oi
           ) {
 
             # okay, we cannot rule it out based on file name; but if
@@ -1400,9 +1418,9 @@ sub run {
             }
             tag 'python-module-in-wrong-location', @correction
               if (@correction);
-            if (    $rest =~ m,^(tests?)(?:\.py|/__init__\.py)$,
-                and $file->is_regular_file) {
-                tag 'python-module-has-overly-generic-name', $fname, "($1)";
+            for my $regex ($GENERIC_PYTHON_MODULES->all) {
+                tag 'python-module-has-overly-generic-name', $fname, "($1)"
+                  if $rest =~ m,^($regex)(?:\.py|/__init__\.py)$,i;
             }
         }
 
