@@ -19,7 +19,7 @@ use warnings;
 use autodie;
 use Carp qw(croak);
 
-use List::MoreUtils qw(any);
+use List::MoreUtils qw(any none);
 
 use Lintian::Data;
 use Lintian::Tags qw(tag);
@@ -30,8 +30,8 @@ our $PYTHON_DEPEND
 our $PYTHON3_DEPEND
   = 'python3:any | python3-dev:any | python3-all:any | python3-all-dev:any';
 our $PYTHON2X_DEPEND = 'python2.7:any | python2.7-dev:any';
-our $PYTHON3X_DEPEND
-  = join(' | ', map { "python${_}:any | python${_}-dev:any" } qw(3.4 3.5));
+our $PYTHON3X_DEPEND= join(' | ',
+    map { "python${_}:any | python${_}-dev:any" } qw(3.4 3.5 3.6 3.7));
 our $ANYPYTHON_DEPEND
   = "$PYTHON_DEPEND | $PYTHON2X_DEPEND | $PYTHON3_DEPEND | $PYTHON3X_DEPEND";
 
@@ -165,7 +165,7 @@ sub run {
     my @arch_rules = (qr/^clean$/, qr/^binary-arch$/, qr/^build-arch$/);
     my @indep_rules = (qr/^build$/, qr/^build-indep$/, qr/^binary-indep$/);
     my (@current_targets, %rules_per_target,  %debhelper_group);
-    my %seen;
+    my (%seen, %overridden);
     my $maybe_skipping;
     my %variables;
     my $uses_makefile_pl = 0;
@@ -308,6 +308,7 @@ sub run {
                 qr/^$_$/;
             } split(' ', $target_dependencies);
             for my $target (@current_targets) {
+                $overridden{$1} = $. if $target =~ m/override_(.+)/;
                 if ($target =~ m/%/o) {
                     my $pattern = quotemeta $target;
                     $pattern =~ s/\\%/.*/g;
@@ -425,6 +426,14 @@ sub run {
         tag 'binary-arch-rules-but-pkg-is-arch-indep' if $nonempty;
     }
 
+    foreach my $suffix (qw(dh_clean dh_fixperms)) {
+        my $line = $overridden{$suffix};
+        tag "override_$suffix-does-not-call-$suffix", "(line $line)"
+          if $line
+          and none { m/^\t\s*-?$suffix\b/ }
+        @{$rules_per_target{"override_$suffix"}};
+    }
+
     # Make sure that all the required build dependencies are there.  Don't
     # issue missing-build-dependency errors for debhelper, since there's
     # another test that does that and it would just be a duplicate.
