@@ -455,9 +455,11 @@ sub run {
             }
             if ($depends && !$all_parsed->implies($depends)) {
                 if ($base =~ /^php/) {
-                    tag 'php-script-but-no-php-cli-dep', $filename;
+                    tag 'php-script-but-no-php-cli-dep', $filename,
+                      "#!$interpreter";
                 } elsif ($base =~ /^(python|ruby|[mg]awk)$/) {
-                    tag("$base-script-but-no-$base-dep", $filename);
+                    tag("$base-script-but-no-$base-dep",
+                        $filename, "#!$interpreter");
                 } elsif ($base eq 'csh' && $filename =~ m,^etc/csh/login\.d/,){
                     # Initialization files for csh.
                 } elsif ($base eq 'fish' && $filename =~ m,^etc/fish\.d/,) {
@@ -468,9 +470,12 @@ sub run {
                         qr/^ocaml(?:-base)?(?:-nox)?-\d\.[\d.]+/)
                   ) {
                     # ABI-versioned virtual packages for ocaml
+                } elsif ($base eq 'escript'
+                    && $all_parsed->matches(qr/^erlang-abi-[\d+\.]+$/)) {
+                    # ABI-versioned virtual packages for erlang
                 } else {
                     tag 'missing-dep-for-interpreter', "$base => $depends",
-                      "($filename)";
+                      "($filename)", "#!$interpreter";
                 }
             }
         } elsif ($VERSIONED_INTERPRETERS->known($base)) {
@@ -487,7 +492,7 @@ sub run {
                     tag "$1-script-but-no-$1-dep", $filename;
                 } else {
                     tag 'missing-dep-for-interpreter', "$base => $depends",
-                      "($filename)";
+                      "($filename)", "#!$interpreter";
                 }
             }
         } else {
@@ -499,7 +504,7 @@ sub run {
                     tag "$1-script-but-no-$1-dep", $filename;
                 } else {
                     tag 'missing-dep-for-interpreter', "$base => $depends",
-                      "($filename)";
+                      "($filename)", "#!$interpreter";
                 }
             }
         }
@@ -710,6 +715,7 @@ sub run {
                 and not m/\bmks?temp\b/
                 and not m/\btempfile\b/
                 and not m/\bmkdir\b/
+                and not m/\bXXXXXX\b/
                 and not m/\$RANDOM/) {
                 #<<< no perltidy - tag name too long
                 tag 'possibly-insecure-handling-of-tmp-files-in-maintainer-script',
