@@ -185,18 +185,22 @@ sub run {
     tag 'debian-watch-contains-dh_make-template' if ($template);
     tag 'debian-watch-may-check-gpg-signature' unless ($withgpgverification);
 
+    # Look for upstream signing key
+    my $key_found = 0;
+    for my $key_name ($SIGNING_KEY_FILENAMES->all) {
+        my $path = $info->index_resolved_path("debian/$key_name");
+        if ($path and $path->is_file) {
+            $key_found = $path;
+            last;
+        }
+    }
+
     if ($withgpgverification) {
-        my $found = 0;
-        for my $key_name ($SIGNING_KEY_FILENAMES->all) {
-            my $path = $info->index_resolved_path("debian/$key_name");
-            if ($path and $path->is_file) {
-                $found = 1;
-                last;
-            }
-        }
-        if (not $found) {
-            tag 'debian-watch-file-pubkey-file-is-missing';
-        }
+        # Check upstream key is present if needed
+        tag 'debian-watch-file-pubkey-file-is-missing' unless $key_found;
+    } else {
+        # Check upstream key is used if present
+        tag 'debian-watch-could-verify-download', $key_found if $key_found;
     }
 
     my $changes = $info->changelog;
